server_client_20141211_234315

### config1 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.19645214081 sec | 4.4108850956 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1.28 | 0.27 | 0.18 | 0.23 | 0.29 | 0.38 | 0.4 | 0.72 | 0.1
qps | 661.00 | 333.67 | 92.00 | 248.00 | 454.50 | 578.40 | 619.70 | 652.74 | 240.06

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1496.18 | 1496.18 | 1496.18 | 1496.18 | 1496.18 | 1496.18 | 1496.18 | 1496.18 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.231
server1-perf | latency | mean lt 0.33 | 0.268915084915
server1-perf | qps | mean lt 7.0 | 333.666666667
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1496.182
client1-perf | latency | mean lt 35.0 | 1496.182
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None